package com.ruoyi.mall.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallPayLog;
import com.ruoyi.mall.service.IMallPayLogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 支付记录Controller
 *
 * @author LCL
 * @date 2023-10-26
 */
@RestController
@RequestMapping("/mall/mallPayLog")
public class MallPayLogController extends BaseController
{
    @Resource
    private IMallPayLogService mallPayLogService;

    /**
     * 查询支付记录列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPayLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallPayLog mallPayLog)
    {
        startPage();
        List<MallPayLog> list = mallPayLogService.selectMallPayLogList(mallPayLog);
        return getDataTable(list);
    }

    /**
     * 导出支付记录列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPayLog:export')")
    @Log(title = "支付记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MallPayLog mallPayLog)
    {
        List<MallPayLog> list = mallPayLogService.selectMallPayLogList(mallPayLog);
        ExcelUtil<MallPayLog> util = new ExcelUtil<MallPayLog>(MallPayLog.class);
        util.exportExcel(response, list, "支付记录数据");
    }

    /**
     * 获取支付记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPayLog:query')")
    @GetMapping(value = "/{payId}")
    public AjaxResult getInfo(@PathVariable("payId") Long payId)
    {
        return AjaxResult.success(mallPayLogService.selectMallPayLogByPayId(payId));
    }

    /**
     * 新增支付记录
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPayLog:add')")
    @Log(title = "支付记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallPayLog mallPayLog)
    {
        return toAjax(mallPayLogService.insertMallPayLog(mallPayLog));
    }

    /**
     * 修改支付记录
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPayLog:edit')")
    @Log(title = "支付记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallPayLog mallPayLog)
    {
        return toAjax(mallPayLogService.updateMallPayLog(mallPayLog));
    }

    /**
     * 删除支付记录
     */
    @PreAuthorize("@ss.hasPermi('mall:mallPayLog:remove')")
    @Log(title = "支付记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{payIds}")
    public AjaxResult remove(@PathVariable Long[] payIds)
    {
        return toAjax(mallPayLogService.deleteMallPayLogByPayIds(payIds));
    }
}
